Distillate

## Settings

Distillate Cloud Token

For cloud sync. Leave blank to skip.

Private GitHub repos

New experiment repos are public by default.

Data

# Distillate

`⌘E` Experiments · `⌘K` Chat · `⌘1-4` Tabs · `⌘R` Refresh · `Esc` Deselect

Type in the chat to talk to Nicolas, or click + New to conjure an experiment.

Tip: run `npm run install:mac` to install Distillate to your Applications folder.

💻

## No active session

Launch an experiment to see the live Claude session here.

📊

## Select an experiment

Pick an experiment from the sidebar to view its runs and insights.

🧪

## No runs yet

Launch a session to start collecting results.

📝

## Select an experiment

Pick an experiment to view its PROMPT.md.

PROMPT.md
Chat
Connecting...
Claude Code